# hdpl/systema/README.md

Note: the Racket modules inside hdpl/systema are the _more low level_
functionality of HDPLisp and as such may contain redundancies (for example
more than one option to return a query) and also are not translated on user
language.

- Trivia:
  - "systēma"
    - https://en.wiktionary.org/wiki/systema#Latin
    - Latin, Etymology: From Ancient Greek σύστημα (sústēma,
      “organised whole, body”), from σύν (sún, “with, together”) + ἵστημι
      (hístēmi, “I stand”).
    - Noun, systēma n (genitive systēmatis); third declension,
      - 1. system
      - 2. harmony

## Potential To Do's

- UN/OCHA Common Operational Datasets
  - (beta testing)
    - https://beta.itos.uga.edu/CODV2API/
      - https://github.com/UGA-ITOSHumanitarianGIS/
      - https://github.com/UGA-ITOSHumanitarianGIS/mapservicedoc
  - https://gistmaps.itos.uga.edu/arcgis/rest/services/COD_External
- redcross.org.uk
  - https://github.com/SimonbJohnson/quickX3/tree/master/hxldash/static/geoms/topojson
- geoboundaries
  - https://www.geoboundaries.org/
  - https://github.com/wmgeolab/geoBoundaries
  - https://www.geoboundaries.org/api.html
